==> haskell-wai-app-static-3.1.4.1-23-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-app-static/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.4.1
id: wai-app-static-3.1.4.1-44f6dcf8d731760c41ac34c914e6b5b3
key: waiap_HTYeeFLF3bR0hkhbg1yQoH
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-app-static-3.1.4.1
hs-libraries: HSwai-app-static-3.1.4.1-HTYeeFLF3bR0hkhbg1yQoH
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
    cryptohash-conduit-0.1.1-6b607828fd72a263de0a99a243d6077b
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    http-date-0.0.6.1-ba351a4841239284d88745a26c501ccf
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
    wai-extra-3.0.14.1-66e8055b51d984feb43fefdbcd17f927
    warp-3.2.3-b193a405602f21fe67837dcb996939ee
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.4.1-28-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-app-static/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.4.1
id: wai-app-static-3.1.4.1-2771ede2f82f698f69c7f5569f69b185
key: waiap_9Lthl3aIGLV3M2sc4lRguz
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-app-static-3.1.4.1
hs-libraries: HSwai-app-static-3.1.4.1-9Lthl3aIGLV3M2sc4lRguz
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
    cryptohash-conduit-0.1.1-9cd42855330eec21f69d5ac4f36d7158
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    http-date-0.0.6.1-757f4a31bc2dcd5d0b4e75509958696c
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    mime-types-0.1.0.6-7d5f22022675c00ea07fd0f1df020c2e
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
    wai-extra-3.0.15-954ac840c460f6e3c2fb191ca01c5fce
    warp-3.2.3-6de819de378ae4c57281b63b66004254
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
